@@ -127,7 +127,7 @@ class CustomFormatter(logging.Formatter):
 
     def format(self, record):
         record.name = record.name.removeprefix('main.')
-        record.msec = record.msec[:2]
+
         if hasattr(record, 'func_name_override'):
             record.funcName = record.func_name_override
         if hasattr(record, 'file_name_override'):
@@ -146,7 +146,7 @@ class CustomFormatter(logging.Formatter):
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime}.{msecs} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime}.{msecs:2} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
